Phase Unwrapping tutorial {#tutorial_unwrap_phase_map}
=======================================================

-	@subpage tutorial_unwrap

	_Compatibility:_ \> OpenCV 3.0.0

	_Author:_ Ambroise Moreau

	You will learn how to use the phase unwrapping module.
